@@ -40,7 +40,7 @@ func TestMatcherJava_matchUpstreamMavenPackage(t *testing.T) {
 		MavenSearcher: newMockSearcher(p),
 	}
 	store := newMockProvider()
-	actual, _ := matcher.matchUpstreamMavenPackages(store, p)
+	actual, _ := matcher.matchUpstreamMavenPackages(store, nil, p)
 
 	assert.Len(t, actual, 2, "unexpected matches count")
 
