@@ -121,7 +121,7 @@ func TestFindMatchesByPackageLanguage(t *testing.T) {
 	store := newMockProviderByLanguage()
 	for _, c := range cases {
 		t.Run(c.p.Name, func(t *testing.T) {
-			actual, err := ByPackageLanguage(store, c.p, match.RubyGemMatcher)
+			actual, err := ByPackageLanguage(store, nil, c.p, match.RubyGemMatcher)
 			assert.NoError(t, err)
 			assertMatchesUsingIDsForVulnerabilities(t, expectedMatch(c.p, c.constraint), actual)
 		})
